==> jc-1.4.0.tar.gz: javax/swing/plaf/basic/BasicToolBarUI__24FrameListener.h <==
// public class javax.swing.plaf.basic.BasicToolBarUI$FrameListener

// class file dependencies
// @dep_class e1cb933811e6d542 java_awt_event_WindowAdapter
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 45737fc4d0c3a6e2 javax_swing_plaf_basic_BasicToolBarUI__24FrameListener

// header file dependencies
// @dep_header java_awt_event_WindowAdapter

#include "java/awt/event/WindowAdapter.h"

#ifndef _JC_javax_swing_plaf_basic_BasicToolBarUI__24FrameListener_H_
#define _JC_javax_swing_plaf_basic_BasicToolBarUI__24FrameListener_H_

// Forward structure declarations
struct _jc_java_awt_event_WindowEvent$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_plaf_basic_BasicToolBarUI$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24FrameListener$sub_refs	_jc_javax_swing_plaf_basic_BasicToolBarUI__24FrameListener$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24FrameListener$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicToolBarUI__24FrameListener$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24FrameListener$refs	_jc_javax_swing_plaf_basic_BasicToolBarUI__24FrameListener$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24FrameListener$nonrefs	_jc_javax_swing_plaf_basic_BasicToolBarUI__24FrameListener$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24FrameListener$object	_jc_javax_swing_plaf_basic_BasicToolBarUI__24FrameListener$object;

typedef const struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24FrameListener$vmethods	_jc_javax_swing_plaf_basic_BasicToolBarUI__24FrameListener$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24FrameListener$vtable	_jc_javax_swing_plaf_basic_BasicToolBarUI__24FrameListener$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24FrameListener$vtype	_jc_javax_swing_plaf_basic_BasicToolBarUI__24FrameListener$vtype;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicToolBarUI__24FrameListener$method$_init$bf41621710f83cec(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24FrameListener$object *, struct _jc_javax_swing_plaf_basic_BasicToolBarUI$object *);

// Virtual methods
extern void _jc_javax_swing_plaf_basic_BasicToolBarUI__24FrameListener$method$windowClosing$023e7b882fa85143(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24FrameListener$object *, struct _jc_java_awt_event_WindowEvent$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_basic_BasicToolBarUI__24FrameListener$method_info$windowClosing$023e7b882fa85143;

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24FrameListener$vmethods {
	void	(*windowClosing$023e7b882fa85143)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24FrameListener$object *, struct _jc_java_awt_event_WindowEvent$object *);
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24FrameListener$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_event_WindowAdapter$vmethods	java_awt_event_WindowAdapter;
	_jc_javax_swing_plaf_basic_BasicToolBarUI__24FrameListener$vmethods	javax_swing_plaf_basic_BasicToolBarUI__24FrameListener;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24FrameListener$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicToolBarUI__24FrameListener$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24FrameListener$sub_refs {
	struct _jc_javax_swing_plaf_basic_BasicToolBarUI$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24FrameListener$refs {
    _jc_javax_swing_plaf_basic_BasicToolBarUI__24FrameListener$sub_refs	javax_swing_plaf_basic_BasicToolBarUI__24FrameListener;
    _jc_java_awt_event_WindowAdapter$sub_refs	java_awt_event_WindowAdapter;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24FrameListener$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24FrameListener$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_event_WindowAdapter$sub_nonrefs	java_awt_event_WindowAdapter;
    _jc_javax_swing_plaf_basic_BasicToolBarUI__24FrameListener$sub_nonrefs	javax_swing_plaf_basic_BasicToolBarUI__24FrameListener;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24FrameListener$object {
	_jc_javax_swing_plaf_basic_BasicToolBarUI__24FrameListener$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicToolBarUI__24FrameListener$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicToolBarUI__24FrameListener$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicToolBarUI__24FrameListener$vtype _jc_javax_swing_plaf_basic_BasicToolBarUI__24FrameListener$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicToolBarUI__24FrameListener, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicToolBarUI__24FrameListener$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicToolBarUI__24FrameListener_H_ */

==> jc-1.4.6.tar.gz: javax/swing/plaf/basic/BasicToolBarUI__24FrameListener.h <==
// public class javax.swing.plaf.basic.BasicToolBarUI$FrameListener

// class file dependencies
// @dep_class e1cb933811e6d542 java_awt_event_WindowAdapter
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 3dd67d6d15b8e8b1 javax_swing_plaf_basic_BasicToolBarUI__24FrameListener

// header file dependencies
// @dep_header java_awt_event_WindowAdapter

#include "java/awt/event/WindowAdapter.h"

#ifndef _JC_javax_swing_plaf_basic_BasicToolBarUI__24FrameListener_H_
#define _JC_javax_swing_plaf_basic_BasicToolBarUI__24FrameListener_H_

// Forward structure declarations
struct _jc_java_awt_event_WindowEvent$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_plaf_basic_BasicToolBarUI$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24FrameListener$sub_refs	_jc_javax_swing_plaf_basic_BasicToolBarUI__24FrameListener$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24FrameListener$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicToolBarUI__24FrameListener$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24FrameListener$refs	_jc_javax_swing_plaf_basic_BasicToolBarUI__24FrameListener$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24FrameListener$nonrefs	_jc_javax_swing_plaf_basic_BasicToolBarUI__24FrameListener$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24FrameListener$object	_jc_javax_swing_plaf_basic_BasicToolBarUI__24FrameListener$object;

typedef const struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24FrameListener$vmethods	_jc_javax_swing_plaf_basic_BasicToolBarUI__24FrameListener$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24FrameListener$vtable	_jc_javax_swing_plaf_basic_BasicToolBarUI__24FrameListener$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24FrameListener$vtype	_jc_javax_swing_plaf_basic_BasicToolBarUI__24FrameListener$vtype;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicToolBarUI__24FrameListener$method$_init$bf41621710f83cec(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24FrameListener$object *, struct _jc_javax_swing_plaf_basic_BasicToolBarUI$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_javax_swing_plaf_basic_BasicToolBarUI__24FrameListener$method$windowClosing$023e7b882fa85143(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24FrameListener$object *, struct _jc_java_awt_event_WindowEvent$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_basic_BasicToolBarUI__24FrameListener$method_info$windowClosing$023e7b882fa85143;

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24FrameListener$vmethods {
	void	(*windowClosing$023e7b882fa85143)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24FrameListener$object *, struct _jc_java_awt_event_WindowEvent$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24FrameListener$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_event_WindowAdapter$vmethods	java_awt_event_WindowAdapter;
	_jc_javax_swing_plaf_basic_BasicToolBarUI__24FrameListener$vmethods	javax_swing_plaf_basic_BasicToolBarUI__24FrameListener;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24FrameListener$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicToolBarUI__24FrameListener$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24FrameListener$sub_refs {
	struct _jc_javax_swing_plaf_basic_BasicToolBarUI$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24FrameListener$refs {
    _jc_javax_swing_plaf_basic_BasicToolBarUI__24FrameListener$sub_refs	javax_swing_plaf_basic_BasicToolBarUI__24FrameListener;
    _jc_java_awt_event_WindowAdapter$sub_refs	java_awt_event_WindowAdapter;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24FrameListener$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24FrameListener$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_event_WindowAdapter$sub_nonrefs	java_awt_event_WindowAdapter;
    _jc_javax_swing_plaf_basic_BasicToolBarUI__24FrameListener$sub_nonrefs	javax_swing_plaf_basic_BasicToolBarUI__24FrameListener;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24FrameListener$object {
	_jc_javax_swing_plaf_basic_BasicToolBarUI__24FrameListener$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicToolBarUI__24FrameListener$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicToolBarUI__24FrameListener$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicToolBarUI__24FrameListener$vtype _jc_javax_swing_plaf_basic_BasicToolBarUI__24FrameListener$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicToolBarUI__24FrameListener, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicToolBarUI__24FrameListener$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicToolBarUI__24FrameListener_H_ */
